@@ -1,6 +1,6 @@
 package Beam::Wire;
 {
-  $Beam::Wire::VERSION = '0.001';
+  $Beam::Wire::VERSION = '0.002';
 }
 
 use strict;
@@ -31,12 +31,22 @@ has services => (
 
 sub get {
     my ( $self, $name ) = @_;
+    if ( $name =~ '/' ) {
+        my ( $container_name, $service ) = split m{/}, $name, 2;
+        my $container = $self->services->{$container_name}
+                      ||= $self->create_service( %{ $self->config->{$container_name} } );
+        return $container->get( $service );
+    }
     return $self->services->{$name} 
         ||= $self->create_service( %{ $self->config->{$name} } );
 }
 
 sub set {
     my ( $self, $name, $service ) = @_;
+    if ( $name =~ '/' ) {
+        my ( $container_name, $service_name ) = split m{/}, $name, 2;
+        return $self->get( $container_name )->set( $service_name, $service );
+    }
     $self->services->{$name} = $service;
 }
 
@@ -55,7 +65,18 @@ sub create_service {
             @args = $service_info{args};
         }
     }
-    @args = $self->find_refs( @args );
+    # Subcontainers cannot scan for refs in their configs
+    if ( $service_info{class}->isa( 'Beam::Wire' ) ) {
+        my %args = @args;
+        my $config = delete $args{config};
+        @args = $self->find_refs( %args );
+        if ( $config ) {
+            push @args, config => $config;
+        }
+    }
+    else {
+        @args = $self->find_refs( @args );
+    }
     return $service_info{class}->new( @args );
 }
 
@@ -180,5 +201,25 @@ Using the array of arguments, you can give arrayrefs or hashrefs:
             -   driver: Memory
                 max_size: 16MB
 
+=head1 INNER CONTAINERS
 
+Beam::Wire objects can hold other Beam::Wire objects!
 
+    inner:
+        class: Beam::Wire
+        args:
+            config:
+                dbh:
+                    class: DBI
+                    args:
+                        - 'dbi:mysql:dbname'
+                cache:
+                    class: CHI
+                    args:
+                        driver: Memory
+                        max_size: 16MB
+
+Inner containers' contents can be reached from outer containers by separating
+the names with a slash character:
+
+    my $dbh = $wire->get( 'inner/dbh' );
